netapp_ontap.models.volume_efficiency API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_efficiency`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeEfficiencySchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeEfficiency object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `application_io_size: str GET POST PATCH`

    Block size to use by compression. 8k and auto are only allowed for POST. Only auto is supported on QAT supported platforms.

    Valid choices:

    - 8k
    - 16k
    - 32k
    - auto
  `auto_state: str GET`

    Automatic deduplication schedule volume state.
    auto ‐ Volumes with auto_state set to auto start post-process deduplication automatically.
    deprioritized ‐ Volumes with auto_state set to deprioritized do not start post-process deduplication automatically.

    Valid choices:

    - auto
    - deprioritized
  `compaction: str GET POST PATCH`

    The system can be enabled/disabled compaction.
    inline ‐ Data will be compacted first and written to the volume.
    none ‐ None
    mixed ‐ Read only field for FlexGroup volumes, where some of the constituent volumes are compaction enabled and some are disabled.

    Valid choices:

    - inline
    - none
    - mixed
  `compression: str GET POST PATCH`

    The system can be enabled/disabled compression. Disabling compression is not allowed on Capacity optimized Flash with QAT supported platforms.
    inline ‐ Data will be compressed first and written to the volume.
    background ‐ Data will be written to the volume and compressed later.
    both ‐ Inline compression compresses the data and write to the volume, background compression compresses only the blocks on which inline compression is not run.
    none ‐ None
    mixed ‐ Read only field for FlexGroup volumes, where some of the constituent volumes are compression enabled and some are disabled.
    Note that On volumes with container compression enabled, background compression refers to inactive data compression scan enabled on the volume.

    Valid choices:

    - inline
    - background
    - both
    - none
    - mixed
  `compression_type: str GET POST PATCH`

    Compression type to use by compression. Valid for PATCH and GET.

    Valid choices:

    - none
    - secondary
    - adaptive
  `cross_volume_dedupe: str GET POST PATCH`

    The system can be enabled/disabled cross volume dedupe. it can be enabled only when dedupe is enabled. Disabling cross volume dedupe is not allowed on Capacity optimized Flash with QAT supported platforms.
    inline ‐ Data will be cross volume deduped first and written to the volume.
    background ‐ Data will be written to the volume and cross volume deduped later.
    both ‐ Inline cross volume dedupe dedupes the data and write to the volume, background cross volume dedupe dedupes only the blocks on which inline dedupe is not run.
    none ‐ None
    mixed ‐ Read only field for FlexGroup volumes, where some of the constituent volumes are cross volume dedupe enabled and some are disabled.

    Valid choices:

    - inline
    - background
    - both
    - none
    - mixed
  `dedupe: str GET POST PATCH`

    The system can be enabled/disabled dedupe. Disabling dedupe is not allowed on Capacity optimized Flash with QAT supported platforms.
    inline ‐ Data will be deduped first and written to the volume.
    background ‐ Data will be written to the volume and deduped later.
    both ‐ Inline dedupe dedupes the data and write to the volume, background dedupe dedupes only the blocks on which inline dedupe is not run.
    none ‐ None
    mixed ‐ Read only field for FlexGroup volumes, where some of the constituent volumes are dedupe enabled and some are disabled.

    Valid choices:

    - inline
    - background
    - both
    - none
    - mixed
  `has_savings: bool GET`

    When true, indicates that the volume contains shared(deduplication, file clones) or compressed data.

  `idcs_scanner: VolumeEfficiencyIdcsScanner GET POST PATCH`

    Inactive data compression scan looks and picks up blocks that have not been read for a certain amount of time(threshold_inactive_days). These blocks are then compressed in 32K chunks. All attributes are valid for GET only, except for 'operation_state' which is valid for PATCH and GET, and is used to start/stop the scanner.

  `last_op_begin: str GET`

    Last sis operation begin timestamp.

  `last_op_end: str GET`

    Last sis operation end timestamp.

  `last_op_err: str GET`

    Last sis operation error text.

  `last_op_size: Size GET`

    Last sis operation size.

  `last_op_state: str GET`

    Last sis operation state.

  `logging_enabled: bool GET`

    When true, indicates that space savings for any newly-written data are being logged.

  `op_state: str GET`

    Sis status of the volume.

    Valid choices:

    - idle
    - initializing
    - active
    - undoing
    - pending
    - downgrading
    - disabled
  `policy: VolumeEfficiencyPolicy1 GET POST PATCH`

    The policy field of the volume_efficiency.

  `progress: str GET`

    Sis progress of the volume.

  `ratio: float GET`

    Storage efficiency that does not include the savings provided by snapshots.

  `scanner: VolumeEfficiencyScanner GET POST PATCH`

    The scanner field of the volume_efficiency.

  `schedule: str GET`

    Schedule associated with volume.

  `space_savings: VolumeEfficiencySpaceSavings GET POST PATCH`

    The space_savings field of the volume_efficiency.

  `state: str GET POST PATCH`

    Storage efficiency state of the volume. Currently, this field supports POST/PATCH only for RW (Read-Write) volumes on FSx for ONTAP and Cloud Volumes ONTAP.
    disabled ‐ All storage efficiency features are disabled.
    mixed ‐ Read-only field for FlexGroup volumes, storage efficiency is enabled on certain constituents and disabled on others.
    On FSx for ONTAP and Cloud Volumes ONTAP ‐
    enabled ‐ All supported storage efficiency features for the volume are enabled.
    custom ‐ Read-only field currently only supported for the FSx for ONTAP and Cloud Volumes ONTAP, user-defined storage efficiency features are enabled.
    For other platforms ‐
    enabled ‐ At least one storage efficiency feature for the volume is enabled.

    Valid choices:

    - disabled
    - enabled
    - mixed
    - custom
  `storage_efficiency_mode: str GET POST PATCH`

    Storage efficiency mode used by volume. This parameter is supported only on AFF platforms. There is no difference between default and efficient modes on QAT supported platforms and auto adaptive compression is set irrespective of the modes.

    Valid choices:

    - default
    - efficient
  `type: str GET`

    Sis Type of the volume.

    Valid choices:

    - regular
    - snapvault
  `volume_path: str GET`

    Absolute volume path of the volume.